package hiter

import "github.com/gohugoio/hugo/common/hiter"

Index

Functions

func Concat

func Concat[V any](seqs ...iter.Seq[V]) iter.Seq[V]

Concat returns an iterator over the concatenation of the sequences. Any nil sequences are ignored.

func Concat2

func Concat2[K, V any](seqs ...iter.Seq2[K, V]) iter.Seq2[K, V]

Concat2 returns an iterator over the concatenation of the sequences. Any nil sequences are ignored.

func Lock

func Lock[V any](seq iter.Seq[V], lock, unlock func()) iter.Seq[V]

Lock returns an iterator that locks before iterating and unlocks after.

func Lock2

func Lock2[K, V any](seq iter.Seq2[K, V], lock, unlock func()) iter.Seq2[K, V]

Lock2 returns an iterator that locks before iterating and unlocks after.

Source Files

iter.go

Version
v0.153.4 (latest)
Published
Dec 28, 2025
Platform
linux/amd64
Imports
1 packages
Last checked
4 months ago

Tools for package owners.