package privacy
import "github.com/gohugoio/hugo/config/privacy"
Index ¶
- type Config
- type Disqus
- type GoogleAnalytics
- type Instagram
- type Service
- type Twitter
- type Vimeo
- type X
- type YouTube
Types ¶
type Config ¶
type Config struct {
Disqus Disqus
GoogleAnalytics GoogleAnalytics
Instagram Instagram
Twitter Twitter `json:"-"` // deprecated in favor of X in v0.141.0
Vimeo Vimeo
YouTube YouTube
X X
}
Config is a privacy configuration for all the relevant services in Hugo.
func DecodeConfig ¶
DecodeConfig creates a privacy Config from a given Hugo configuration.
type Disqus ¶
type Disqus struct {
Service `mapstructure:",squash"`
}
Disqus holds the privacy configuration settings related to the Disqus template.
type GoogleAnalytics ¶
type GoogleAnalytics struct {
Service `mapstructure:",squash"`
// Enabling this will make the GA templates respect the
// "Do Not Track" HTTP header. See https://www.paulfurley.com/google-analytics-dnt/.
RespectDoNotTrack bool
}
GoogleAnalytics holds the privacy configuration settings related to the Google Analytics template.
type Instagram ¶
type Instagram struct {
Service `mapstructure:",squash"`
// If simple mode is enabled, a static and no-JS version of the Instagram
// image card will be built.
Simple bool
}
Instagram holds the privacy configuration settings related to the Instagram shortcode.
type Service ¶
type Service struct {
Disable bool
}
Service is the common values for a service in a policy definition.
type Twitter ¶
type Twitter struct {
Service `mapstructure:",squash"`
// When set to true, the Tweet and its embedded page on your site are not used
// for purposes that include personalized suggestions and personalized ads.
EnableDNT bool
// If simple mode is enabled, a static and no-JS version of the Tweet will be built.
Simple bool
}
Twitter holds the privacy configuration settings related to the Twitter shortcode. Deprecated in favor of X in v0.141.0.
type Vimeo ¶
type Vimeo struct {
Service `mapstructure:",squash"`
// When set to true, the Vimeo player will be blocked from tracking any session data,
// including all cookies and stats.
EnableDNT bool
// If simple mode is enabled, only a thumbnail is fetched from i.vimeocdn.com and
// shown with a play button overlaid. If a user clicks the button, he/she will
// be taken to the video page on vimeo.com in a new browser tab.
Simple bool
}
Vimeo holds the privacy configuration settings related to the Vimeo shortcode.
type X ¶
type X struct {
Service `mapstructure:",squash"`
// When set to true, the X post and its embedded page on your site are not
// used for purposes that include personalized suggestions and personalized
// ads.
EnableDNT bool
// If simple mode is enabled, a static and no-JS version of the X post will
// be built.
Simple bool
}
X holds the privacy configuration settings related to the X shortcode.
type YouTube ¶
type YouTube struct {
Service `mapstructure:",squash"`
// When you turn on privacy-enhanced mode,
// YouTube won’t store information about visitors on your website
// unless the user plays the embedded video.
PrivacyEnhanced bool
}
YouTube holds the privacy configuration settings related to the YouTube shortcode.
Source Files ¶
- Version
- v0.153.4 (latest)
- Published
- Dec 28, 2025
- Platform
- linux/amd64
- Imports
- 2 packages
- Last checked
- 4 months ago –
Tools for package owners.