package hooks
import "github.com/gohugoio/hugo/markup/converter/hooks"
Index ¶
- type AttributesOptionsSliceProvider
- type AttributesProvider
- type BaseContext
- type BlockquoteContext
- type BlockquoteRenderer
- type CodeBlockRenderer
- type CodeblockContext
- type ElementPositionResolver
- type GetRendererFunc
- type HeadingContext
- type HeadingRenderer
- type ImageLinkContext
- type IsDefaultCodeBlockRendererProvider
- type LinkContext
- type LinkRenderer
- type PageProvider
- type PassthroughContext
- type PassthroughRenderer
- type PositionerSourceTargetProvider
- type RendererType
- type Table
- type TableCell
- type TableContext
- type TableRenderer
- type TableRow
Types ¶
type AttributesOptionsSliceProvider ¶
type AttributesOptionsSliceProvider interface {
AttributesSlice() []attributes.Attribute
OptionsSlice() []attributes.Attribute
}
type AttributesProvider ¶
type AttributesProvider interface {
// Attributes passed in from Markdown (e.g. { attrName1=attrValue1 attrName2="attr Value 2" }).
Attributes() map[string]any
}
type BaseContext ¶
type BaseContext interface {
text.Positioner
PageProvider
// Zero-based ordinal for all elements of this kind in the current document.
Ordinal() int
}
BaseContext is the base context used in most render hooks.
type BlockquoteContext ¶
type BlockquoteContext interface {
BaseContext
AttributesProvider
// The blockquote text.
// If type is "alert", this will be the alert text.
Text() hstring.HTML
/// Returns the blockquote type, one of "regular" and "alert".
// Type "alert" indicates that this is a GitHub type alert.
Type() string
// The GitHub alert type converted to lowercase, e.g. "note".
// Only set if Type is "alert".
AlertType() string
// The alert title.
// Currently only relevant for Obsidian alerts.
// GitHub does not suport alert titles and will not render alerts with titles.
AlertTitle() hstring.HTML
// The alert sign, "+" or "-" or "" used to indicate folding.
// Currently only relevant for Obsidian alerts.
// GitHub does not suport alert signs and will not render alerts with signs.
AlertSign() string
}
BlockquoteContext is the context passed to a blockquote render hook.
type BlockquoteRenderer ¶
type BlockquoteRenderer interface {
RenderBlockquote(cctx context.Context, w hugio.FlexiWriter, ctx BlockquoteContext) error
}
type CodeBlockRenderer ¶
type CodeBlockRenderer interface {
RenderCodeblock(cctx context.Context, w hugio.FlexiWriter, ctx CodeblockContext) error
}
type CodeblockContext ¶
type CodeblockContext interface {
BaseContext
AttributesProvider
// Chroma highlighting processing options. This will only be filled if Type is a known Chroma Lexer.
Options() map[string]any
// The type of code block. This will be the programming language, e.g. bash, when doing code highlighting.
Type() string
// The text between the code fences.
Inner() string
}
CodeblockContext is the context passed to a code block render hook.
type ElementPositionResolver ¶
ElementPositionResolver provides a way to resolve the start Position of a markdown element in the original source document. This may be both slow and approximate, so should only be used for error logging.
type GetRendererFunc ¶
type GetRendererFunc func(t RendererType, id any) any
type HeadingContext ¶
type HeadingContext interface {
PageProvider
// Level is the level of the header (i.e. 1 for top-level, 2 for sub-level, etc.).
Level() int
// Anchor is the HTML id assigned to the heading.
Anchor() string
// Text is the rendered (HTML) heading text, excluding the heading marker.
Text() hstring.HTML
// PlainText is the unrendered version of Text.
PlainText() string
// Attributes (e.g. CSS classes)
AttributesProvider
}
HeadingContext contains accessors to all attributes that a HeadingRenderer can use to render a heading.
type HeadingRenderer ¶
type HeadingRenderer interface {
// RenderHeading writes the rendered content to w using the data in w.
RenderHeading(cctx context.Context, w io.Writer, ctx HeadingContext) error
}
HeadingRenderer describes a uniquely identifiable rendering hook.
type ImageLinkContext ¶
type ImageLinkContext interface {
LinkContext
// Returns true if this is a standalone image and the config option
// markup.goldmark.parser.wrapStandAloneImageWithinParagraph is disabled.
IsBlock() bool
// Zero-based ordinal for all the images in the current document.
Ordinal() int
}
ImageLinkContext is the context passed to a image link render hook.
type IsDefaultCodeBlockRendererProvider ¶
type IsDefaultCodeBlockRendererProvider interface {
IsDefaultCodeBlockRenderer() bool
}
type LinkContext ¶
type LinkContext interface {
PageProvider
// The link URL.
Destination() string
// The link title attribute.
Title() string
// The rendered (HTML) text.
Text() hstring.HTML
// The plain variant of Text.
PlainText() string
}
LinkContext is the context passed to a link render hook.
type LinkRenderer ¶
type LinkRenderer interface {
RenderLink(cctx context.Context, w io.Writer, ctx LinkContext) error
}
type PageProvider ¶
type PageProvider interface {
// Page is the page being rendered.
Page() any
// PageInner may be different than Page when .RenderShortcodes is in play.
// The main use case for this is to include other pages' markdown into the current page
// but resolve resources and pages relative to the original.
PageInner() any
}
type PassthroughContext ¶
type PassthroughContext interface {
BaseContext
AttributesProvider
// Currently one of "inline" or "block".
Type() string
// The inner content of the passthrough element, excluding the delimiters.
Inner() string
}
PassThroughContext is the context passed to a passthrough render hook.
type PassthroughRenderer ¶
type PassthroughRenderer interface {
RenderPassthrough(cctx context.Context, w io.Writer, ctx PassthroughContext) error
}
type PositionerSourceTargetProvider ¶
type PositionerSourceTargetProvider interface {
// For internal use.
PositionerSourceTarget() []byte
}
type RendererType ¶
type RendererType int
const ( LinkRendererType RendererType = iota + 1 ImageRendererType HeadingRendererType CodeBlockRendererType PassthroughRendererType BlockquoteRendererType TableRendererType )
type Table ¶
type TableCell ¶
type TableContext ¶
type TableContext interface {
BaseContext
AttributesProvider
THead() []TableRow
TBody() []TableRow
}
TableContext is the context passed to a table render hook.
type TableRenderer ¶
type TableRenderer interface {
RenderTable(cctx context.Context, w hugio.FlexiWriter, ctx TableContext) error
}
type TableRow ¶
type TableRow []TableCell
Source Files ¶
- Version
- v0.153.4 (latest)
- Published
- Dec 28, 2025
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 4 months ago –
Tools for package owners.