package goldmark_config
import "github.com/gohugoio/hugo/markup/goldmark/goldmark_config"
Package goldmark_config holds Goldmark related configuration.
Index ¶
- Constants
- Variables
- type CJK
- type Config
- type Delete
- type DelimitersConfig
- type Extensions
- type Extras
- type Footnote
- type ImageRenderHook
- type Insert
- type LinkRenderHook
- type Mark
- type Parser
- type ParserAttribute
- type Passthrough
- type RenderHooks
- type Renderer
- type Subscript
- type Superscript
- type Typographer
Constants ¶
const ( AutoIDTypeBlackfriday = "blackfriday" AutoIDTypeGitHub = "github" AutoIDTypeGitHubAscii = "github-ascii" RenderHookUseEmbeddedAlways = "always" RenderHookUseEmbeddedAuto = "auto" RenderHookUseEmbeddedFallback = "fallback" RenderHookUseEmbeddedNever = "never" )
Variables ¶
var Default = Config{ Extensions: Extensions{ Typographer: Typographer{ Disable: false, LeftSingleQuote: "‘", RightSingleQuote: "’", LeftDoubleQuote: "“", RightDoubleQuote: "”", EnDash: "–", EmDash: "—", Ellipsis: "…", LeftAngleQuote: "«", RightAngleQuote: "»", Apostrophe: "’", }, Footnote: Footnote{ Enable: true, EnableAutoIDPrefix: false, BacklinkHTML: "↩︎", }, DefinitionList: true, Table: true, Strikethrough: true, Linkify: true, LinkifyProtocol: "https", TaskList: true, CJK: CJK{ Enable: false, EastAsianLineBreaks: false, EastAsianLineBreaksStyle: "simple", EscapedSpace: false, }, Extras: Extras{ Delete: Delete{ Enable: false, }, Insert: Insert{ Enable: false, }, Mark: Mark{ Enable: false, }, Subscript: Subscript{ Enable: false, }, Superscript: Superscript{ Enable: false, }, }, Passthrough: Passthrough{ Enable: false, Delimiters: DelimitersConfig{ Inline: [][]string{}, Block: [][]string{}, }, }, }, Renderer: Renderer{ Unsafe: false, }, Parser: Parser{ AutoHeadingID: true, AutoDefinitionTermID: false, AutoIDType: AutoIDTypeGitHub, WrapStandAloneImageWithinParagraph: true, Attribute: ParserAttribute{ Title: true, Block: false, }, }, RenderHooks: RenderHooks{ Image: ImageRenderHook{ UseEmbedded: RenderHookUseEmbeddedAuto, }, Link: LinkRenderHook{ UseEmbedded: RenderHookUseEmbeddedAuto, }, }, }
Default holds the default Goldmark configuration.
Types ¶
type CJK ¶
type CJK struct {
// Whether to enable CJK support.
Enable bool
// Whether softline breaks between east asian wide characters should be ignored.
EastAsianLineBreaks bool
// Styles of Line Breaking of EastAsianLineBreaks: "simple" or "css3draft"
EastAsianLineBreaksStyle string
// Whether a '\' escaped half-space(0x20) should not be rendered.
EscapedSpace bool
}
type Config ¶
type Config struct {
Renderer Renderer
Parser Parser
Extensions Extensions
DuplicateResourceFiles bool
RenderHooks RenderHooks
}
Config configures Goldmark.
func (*Config) Init ¶
type Delete ¶
type Delete struct {
Enable bool
}
type DelimitersConfig ¶
type DelimitersConfig struct {
// The delimiters to use for inline passthroughs. Each entry in the list
// is a size-2 list of strings, where the first string is the opening delimiter
// and the second string is the closing delimiter, e.g.,
//
// [["$", "$"], ["\\(", "\\)"]]
Inline [][]string
// The delimiters to use for block passthroughs. Same format as Inline.
Block [][]string
}
type Extensions ¶
type Extensions struct {
Typographer Typographer
Footnote Footnote
DefinitionList bool
Extras Extras
Passthrough Passthrough
// GitHub flavored markdown
Table bool
Strikethrough bool
Linkify bool
LinkifyProtocol string
TaskList bool
CJK CJK
}
type Extras ¶
type Extras struct {
Delete Delete
Insert Insert
Mark Mark
Subscript Subscript
Superscript Superscript
}
Extras holds extras configuration. github.com/hugoio/hugo-goldmark-extensions/extras
type Footnote ¶
Footnote holds footnote configuration.
type ImageRenderHook ¶
type ImageRenderHook struct {
// Enable the default image render hook.
// We need to know if it is set or not, hence the pointer.
// Deprecated: Use UseEmbedded instead.
EnableDefault *bool
// When to use the embedded image render hook.
// One of auto, never, always, or fallback. Default is auto.
UseEmbedded string
}
ImageRenderHook contains configuration for the image render hook.
type Insert ¶
type Insert struct {
Enable bool
}
type LinkRenderHook ¶
type LinkRenderHook struct {
// Disable the default image render hook.
// We need to know if it is set or not, hence the pointer.
// Deprecated: Use UseEmbedded instead.
EnableDefault *bool
// When to use the embedded link render hook.
// One of auto, never, always, or fallback. Default is auto.
UseEmbedded string
}
LinkRenderHook contains configuration for the link render hook.
type Mark ¶
type Mark struct {
Enable bool
}
type Parser ¶
type Parser struct {
// Enables custom heading ids and
// auto generated heading ids.
AutoHeadingID bool
// Enables auto definition term ids.
AutoDefinitionTermID bool
// The strategy to use when generating IDs.
// Available options are "github", "github-ascii", and "blackfriday".
// Default is "github", which will create GitHub-compatible anchor names.
AutoIDType string
// Enables custom attributes.
Attribute ParserAttribute
// Whether to wrap stand-alone images within a paragraph or not.
WrapStandAloneImageWithinParagraph bool
// Renamed to AutoIDType in 0.144.0.
AutoHeadingIDType string `json:"-"`
}
func (*Parser) Init ¶
type ParserAttribute ¶
type ParserAttribute struct {
// Enables custom attributes for titles.
Title bool
// Enables custom attributes for blocks.
Block bool
}
type Passthrough ¶
type Passthrough struct {
// Whether to enable the extension
Enable bool
// The delimiters to use for inline and block passthroughs.
Delimiters DelimitersConfig
}
Passthrough holds passthrough configuration. github.com/hugoio/hugo-goldmark-extensions/passthrough
type RenderHooks ¶
type RenderHooks struct {
Image ImageRenderHook
Link LinkRenderHook
}
RenderHooks contains configuration for Goldmark render hooks.
type Renderer ¶
type Renderer struct {
// Whether softline breaks should be rendered as '<br>'
HardWraps bool
// XHTML instead of HTML5.
XHTML bool
// Allow raw HTML etc.
Unsafe bool
}
type Subscript ¶
type Subscript struct {
Enable bool
}
type Superscript ¶
type Superscript struct {
Enable bool
}
type Typographer ¶
type Typographer struct {
// Whether to disable typographer.
Disable bool
// Value used for left single quote.
LeftSingleQuote string
// Value used for right single quote.
RightSingleQuote string
// Value used for left double quote.
LeftDoubleQuote string
// Value used for right double quote.
RightDoubleQuote string
// Value used for en dash.
EnDash string
// Value used for em dash.
EmDash string
// Value used for ellipsis.
Ellipsis string
// Value used for left angle quote.
LeftAngleQuote string
// Value used for right angle quote.
RightAngleQuote string
// Value used for apostrophe.
Apostrophe string
}
Typographer holds typographer configuration.
Source Files ¶
- Version
- v0.153.4 (latest)
- Published
- Dec 28, 2025
- Platform
- linux/amd64
- Last checked
- 4 months ago –
Tools for package owners.