package publisher
import "github.com/gohugoio/hugo/publisher"
Index ¶
- type Descriptor
- type DestinationPublisher
- func NewDestinationPublisher(rs *resources.Spec, outputFormats output.Formats, mediaTypes media.Types) (pub DestinationPublisher, err error)
- func (p DestinationPublisher) Publish(d Descriptor) error
- func (p DestinationPublisher) PublishStats() PublishStats
- type HTMLElements
- type PublishStats
- type Publisher
Types ¶
type Descriptor ¶
type Descriptor struct {
// The content to publish.
Src io.Reader
// The OutputFormat of the this content.
OutputFormat output.Format
// Where to publish this content. This is a filesystem-relative path.
TargetPath string
// Counter for the end build summary.
StatCounter *uint64
// Configuration that trigger pre-processing.
// LiveReload script will be injected if this is != nil
LiveReloadBaseURL *url.URL
// Enable to inject the Hugo generated tag in the header. Is currently only
// injected on the home page for HTML type of output formats.
AddHugoGeneratorTag bool
// If set, will replace all relative URLs with this one.
AbsURLPath string
// Enable to minify the output using the OutputFormat defined above to
// pick the correct minifier configuration.
Minify bool
}
Descriptor describes the needed publishing chain for an item.
type DestinationPublisher ¶
type DestinationPublisher struct {
// contains filtered or unexported fields
}
DestinationPublisher is the default and currently only publisher in Hugo. This publisher prepares and publishes an item to the defined destination, e.g. /public.
func NewDestinationPublisher ¶
func NewDestinationPublisher(rs *resources.Spec, outputFormats output.Formats, mediaTypes media.Types) (pub DestinationPublisher, err error)
NewDestinationPublisher creates a new DestinationPublisher.
func (DestinationPublisher) Publish ¶
func (p DestinationPublisher) Publish(d Descriptor) error
Publish applies any relevant transformations and writes the file to its destination, e.g. /public.
func (DestinationPublisher) PublishStats ¶
func (p DestinationPublisher) PublishStats() PublishStats
type HTMLElements ¶
type HTMLElements struct {
Tags []string `json:"tags"`
Classes []string `json:"classes"`
IDs []string `json:"ids"`
}
HTMLElements holds lists of tags and attribute values for classes and id.
func (*HTMLElements) Merge ¶
func (h *HTMLElements) Merge(other HTMLElements)
func (*HTMLElements) Sort ¶
func (h *HTMLElements) Sort()
type PublishStats ¶
type PublishStats struct {
HTMLElements HTMLElements `json:"htmlElements"`
}
type Publisher ¶
type Publisher interface {
Publish(d Descriptor) error
PublishStats() PublishStats
}
Publisher publishes a result file.
Source Files ¶
htmlElementsCollector.go publisher.go
- Version
- v0.153.4 (latest)
- Published
- Dec 28, 2025
- Platform
- linux/amd64
- Imports
- 26 packages
- Last checked
- 4 months ago –
Tools for package owners.