package exif
import "github.com/gohugoio/hugo/resources/images/exif"
Index ¶
- func ExcludeFields(expression string) func(*Decoder) error
- func IncludeFields(expression string) func(*Decoder) error
- func WithDateDisabled(disabled bool) func(*Decoder) error
- func WithLatLongDisabled(disabled bool) func(*Decoder) error
- func WithWarnLogger(warnl logg.LevelLogger) func(*Decoder) error
- type Decoder
- func NewDecoder(options ...func(*Decoder) error) (*Decoder, error)
- func (d *Decoder) Decode(filename string, format imagemeta.ImageFormat, r io.Reader) (ex *ExifInfo, err error)
- type ExifInfo
- type Tags
Functions ¶
func ExcludeFields ¶
func IncludeFields ¶
func WithDateDisabled ¶
func WithLatLongDisabled ¶
func WithWarnLogger ¶
func WithWarnLogger(warnl logg.LevelLogger) func(*Decoder) error
Types ¶
type Decoder ¶
type Decoder struct {
// contains filtered or unexported fields
}
func NewDecoder ¶
func (*Decoder) Decode ¶
func (d *Decoder) Decode(filename string, format imagemeta.ImageFormat, r io.Reader) (ex *ExifInfo, err error)
Filename is only used for logging.
type ExifInfo ¶
type ExifInfo struct {
// GPS latitude in degrees.
Lat float64
// GPS longitude in degrees.
Long float64
// Image creation date/time.
Date time.Time
// A collection of the available Exif tags for this Image.
Tags Tags
}
ExifInfo holds the decoded Exif data for an Image.
type Tags ¶
Tags is a map of EXIF tags.
func (Tags) MarshalJSON ¶
MarshalJSON is for internal use only.
func (*Tags) UnmarshalJSON ¶
UnmarshalJSON is for internal use only.
Source Files ¶
- Version
- v0.153.4 (latest)
- Published
- Dec 28, 2025
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 4 months ago –
Tools for package owners.