package jsconfig
import "github.com/gohugoio/hugo/resources/jsconfig"
Index ¶
- type Builder
- func NewBuilder() *Builder
- func (b *Builder) AddSourceRoot(root string)
- func (b *Builder) Build(dir string) *Config
- type CompilerOptions
- type Config
Types ¶
type Builder ¶
type Builder struct {
// contains filtered or unexported fields
}
Builder builds a jsconfig.json file that, currently, is used only to assist IntelliSense in editors.
func NewBuilder ¶
func NewBuilder() *Builder
NewBuilder creates a new Builder.
func (*Builder) AddSourceRoot ¶
AddSourceRoot adds a new source root. This method is thread safe.
func (*Builder) Build ¶
Build builds a new Config with paths relative to dir. This method is thread safe.
type CompilerOptions ¶
type CompilerOptions struct {
BaseURL string `json:"baseUrl"`
Paths map[string][]string `json:"paths"`
}
CompilerOptions holds compilerOptions for jsonconfig.json.
type Config ¶
type Config struct {
CompilerOptions CompilerOptions `json:"compilerOptions"`
}
Config holds the data for jsconfig.json.
Source Files ¶
- Version
- v0.153.4 (latest)
- Published
- Dec 28, 2025
- Platform
- linux/amd64
- Imports
- 3 packages
- Last checked
- 4 months ago –
Tools for package owners.