package images
import "github.com/gohugoio/hugo/tpl/images"
Package images provides template functions for manipulating images.
Index ¶
Types ¶
type Namespace ¶
type Namespace struct {
*images.Filters
// contains filtered or unexported fields
}
Namespace provides template functions for the "images" namespace.
func New ¶
func New(d *deps.Deps) *Namespace
New returns a new instance of the images-namespaced template functions.
func (*Namespace) Config ¶
Config returns the image.Config for the specified path relative to the working directory.
func (*Namespace) Filter ¶
Filter applies the given filters to the image given as the last element in args.
func (*Namespace) QR ¶
QR encodes the given text into a QR code using the specified options, returning an image resource.
Source Files ¶
- Version
- v0.165.0 (latest)
- Published
- Aug 12, 2026
- Platform
- linux/amd64
- Imports
- 18 packages
- Last checked
- 3 hours ago –
Tools for package owners.