css

package
v0.158.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: Apache-2.0 Imports: 20 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Namespace

type Namespace struct {
	// contains filtered or unexported fields
}

Namespace provides template functions for the "css" namespace.

func (*Namespace) Build added in v0.158.0

func (ns *Namespace) Build(args ...any) (resource.Resource, error)

Build processes the given CSS Resource with ESBuild. Note that this method is identical to the one in the js Namespace.

func (*Namespace) PostCSS added in v0.128.0

func (ns *Namespace) PostCSS(args ...any) (resource.Resource, error)

PostCSS processes the given Resource with PostCSS.

func (*Namespace) Quoted

func (ns *Namespace) Quoted(v any) css.QuotedString

Quoted returns a string that needs to be quoted in CSS.

func (*Namespace) Sass added in v0.128.0

func (ns *Namespace) Sass(args ...any) (resource.Resource, error)

Sass processes the given Resource with SASS.

func (*Namespace) TailwindCSS added in v0.128.0

func (ns *Namespace) TailwindCSS(args ...any) (resource.Resource, error)

TailwindCSS processes the given Resource with tailwindcss.

func (*Namespace) Unquoted

func (ns *Namespace) Unquoted(v any) css.UnquotedString

Unquoted returns a string that does not need to be quoted in CSS.

Jump to