package templates
import "github.com/gohugoio/hugo/tpl/templates"
Package templates provides template functions for working with templates.
Index ¶
Types ¶
type DeferOpts ¶
type DeferOpts struct {
// Optional cache key. If set, the deferred block will be executed
// once per unique key.
Key string
// Optional data context to use when executing the deferred block.
Data any
}
type Namespace ¶
type Namespace struct {
// contains filtered or unexported fields
}
Namespace provides template functions for the "templates" namespace.
func New ¶
New returns a new instance of the templates-namespaced template functions.
func (*Namespace) Current ¶
func (ns *Namespace) Current(ctx context.Context) *tpl.CurrentTemplateInfo
Get information about the currently executing template.
func (*Namespace) Defer ¶
Defer defers the execution of a template block.
func (*Namespace) DoDefer ¶
DoDefer defers the execution of a template block. For internal use only.
func (*Namespace) Exists ¶
Exists returns whether the template with the given name exists. Note that this is the Unix-styled relative path including filename suffix, e.g. partials/header.html
Source Files ¶
- Version
- v0.153.4 (latest)
- Published
- Dec 28, 2025
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 4 months ago –
Tools for package owners.